"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.mdb.kafka.v1.common_pb2
import yandex.cloud.mdb.kafka.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """An Apache Kafka® cluster resource.
    For more information, see the [Concepts](/docs/managed-kafka/concepts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy when only hotfixes are applied during regular maintenance."""
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with a more aggressive update policy when new versions are rolled out irrespective of backward compatibility."""

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy when only hotfixes are applied during regular maintenance."""
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with a more aggressive update policy when new versions are rolled out irrespective of backward compatibility."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] of all hosts in the cluster is `UNKNOWN`)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] of all hosts in the cluster is `ALIVE`)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] of all hosts in the cluster is `DEAD`)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is in degraded state ([Host.health] of at least one of the hosts in the cluster is not `ALIVE`)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Apache Kafka® cluster.
    This ID is assigned at creation time.
    """
    folder_id: builtins.str
    """ID of the folder that the Apache Kafka® cluster belongs to."""
    name: builtins.str
    """Name of the Apache Kafka® cluster.
    The name must be unique within the folder. 1-63 characters long. Value must match the regular expression `[a-zA-Z0-9_-]*`.
    """
    description: builtins.str
    """Description of the Apache Kafka® cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the Apache Kafka® cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Apache Kafka® cluster as `key:value` pairs.
        A maximum of 64 labels per resource is allowed.
        """

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the Apache Kafka® cluster."""

    @property
    def config(self) -> global___ConfigSpec:
        """Configuration of the Apache Kafka® cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the cluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceOperation:
        """Scheduled maintenance operation."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ConfigSpec | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.kafka.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "host_group_ids", b"host_group_ids", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Metadata of monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the Apache Kafka® cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Kafka(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCES_FIELD_NUMBER: builtins.int
        KAFKA_CONFIG_2_8_FIELD_NUMBER: builtins.int
        KAFKA_CONFIG_3_FIELD_NUMBER: builtins.int
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to Kafka brokers."""

        @property
        def kafka_config_2_8(self) -> global___KafkaConfig2_8: ...
        @property
        def kafka_config_3(self) -> global___KafkaConfig3: ...
        def __init__(
            self,
            *,
            resources: global___Resources | None = ...,
            kafka_config_2_8: global___KafkaConfig2_8 | None = ...,
            kafka_config_3: global___KafkaConfig3 | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["kafka_config", b"kafka_config", "kafka_config_2_8", b"kafka_config_2_8", "kafka_config_3", b"kafka_config_3", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["kafka_config", b"kafka_config", "kafka_config_2_8", b"kafka_config_2_8", "kafka_config_3", b"kafka_config_3", "resources", b"resources"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["kafka_config", b"kafka_config"]) -> typing.Literal["kafka_config_2_8", "kafka_config_3"] | None: ...

    @typing.final
    class Zookeeper(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCES_FIELD_NUMBER: builtins.int
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to ZooKeeper hosts."""

        def __init__(
            self,
            *,
            resources: global___Resources | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

    @typing.final
    class RestAPIConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """Is REST API enabled for this cluster."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

    VERSION_FIELD_NUMBER: builtins.int
    KAFKA_FIELD_NUMBER: builtins.int
    ZOOKEEPER_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    BROKERS_COUNT_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    UNMANAGED_TOPICS_FIELD_NUMBER: builtins.int
    SCHEMA_REGISTRY_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    REST_API_CONFIG_FIELD_NUMBER: builtins.int
    DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of Apache Kafka® used in the cluster. Possible values: `2.1`, `2.6`."""
    assign_public_ip: builtins.bool
    """The flag that defines whether a public IP address is assigned to the cluster.
    If the value is `true`, then Apache Kafka® cluster is available on the Internet via it's public IP address.
    """
    unmanaged_topics: builtins.bool
    """Allows to manage topics via AdminAPI
    Deprecated. Feature enabled permanently.
    """
    schema_registry: builtins.bool
    """Enables managed schema registry on cluster"""
    @property
    def kafka(self) -> global___ConfigSpec.Kafka:
        """Configuration and resource allocation for Kafka brokers."""

    @property
    def zookeeper(self) -> global___ConfigSpec.Zookeeper:
        """Configuration and resource allocation for ZooKeeper hosts."""

    @property
    def zone_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of availability zones where Kafka brokers reside."""

    @property
    def brokers_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of Kafka brokers deployed in each availability zone."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    @property
    def rest_api_config(self) -> global___ConfigSpec.RestAPIConfig:
        """Configuration of REST API."""

    @property
    def disk_size_autoscaling(self) -> global___DiskSizeAutoscaling:
        """DiskSizeAutoscaling settings"""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        kafka: global___ConfigSpec.Kafka | None = ...,
        zookeeper: global___ConfigSpec.Zookeeper | None = ...,
        zone_id: collections.abc.Iterable[builtins.str] | None = ...,
        brokers_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        assign_public_ip: builtins.bool = ...,
        unmanaged_topics: builtins.bool = ...,
        schema_registry: builtins.bool = ...,
        access: global___Access | None = ...,
        rest_api_config: global___ConfigSpec.RestAPIConfig | None = ...,
        disk_size_autoscaling: global___DiskSizeAutoscaling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "brokers_count", b"brokers_count", "disk_size_autoscaling", b"disk_size_autoscaling", "kafka", b"kafka", "rest_api_config", b"rest_api_config", "zookeeper", b"zookeeper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "assign_public_ip", b"assign_public_ip", "brokers_count", b"brokers_count", "disk_size_autoscaling", b"disk_size_autoscaling", "kafka", b"kafka", "rest_api_config", b"rest_api_config", "schema_registry", b"schema_registry", "unmanaged_topics", b"unmanaged_topics", "version", b"version", "zone_id", b"zone_id", "zookeeper", b"zookeeper"]) -> None: ...

global___ConfigSpec = ConfigSpec

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory, etc.).
    All available presets are listed in the [documentation](/docs/managed-kafka/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes. Must be greater than 2 * partition segment size in bytes * partitions count, so each partition can have one active segment file and one closed segment file that can be deleted."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class KafkaConfig2_8(google.protobuf.message.Message):
    """Kafka version 2.8 broker configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    LOG_FLUSH_INTERVAL_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_FLUSH_INTERVAL_MS_FIELD_NUMBER: builtins.int
    LOG_FLUSH_SCHEDULER_INTERVAL_MS_FIELD_NUMBER: builtins.int
    LOG_RETENTION_BYTES_FIELD_NUMBER: builtins.int
    LOG_RETENTION_HOURS_FIELD_NUMBER: builtins.int
    LOG_RETENTION_MINUTES_FIELD_NUMBER: builtins.int
    LOG_RETENTION_MS_FIELD_NUMBER: builtins.int
    LOG_SEGMENT_BYTES_FIELD_NUMBER: builtins.int
    LOG_PREALLOCATE_FIELD_NUMBER: builtins.int
    SOCKET_SEND_BUFFER_BYTES_FIELD_NUMBER: builtins.int
    SOCKET_RECEIVE_BUFFER_BYTES_FIELD_NUMBER: builtins.int
    AUTO_CREATE_TOPICS_ENABLE_FIELD_NUMBER: builtins.int
    NUM_PARTITIONS_FIELD_NUMBER: builtins.int
    DEFAULT_REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    MESSAGE_MAX_BYTES_FIELD_NUMBER: builtins.int
    REPLICA_FETCH_MAX_BYTES_FIELD_NUMBER: builtins.int
    SSL_CIPHER_SUITES_FIELD_NUMBER: builtins.int
    OFFSETS_RETENTION_MINUTES_FIELD_NUMBER: builtins.int
    SASL_ENABLED_MECHANISMS_FIELD_NUMBER: builtins.int
    compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType
    """Cluster topics compression type."""
    @property
    def log_flush_interval_messages(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of messages accumulated on a log partition before messages are flushed to disk.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.flush_messages] setting.
        """

    @property
    def log_flush_interval_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time (in milliseconds) that a message in any topic is kept in memory before flushed to disk.
        If not set, the value of [log_flush_scheduler_interval_ms] is used.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.flush_ms] setting.
        """

    @property
    def log_flush_scheduler_interval_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The frequency of checks (in milliseconds) for any logs that need to be flushed to disk.
        This check is done by the log flusher.
        """

    @property
    def log_retention_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Partition size limit; Kafka will discard old log segments to free up space if `delete` [TopicConfig2_8.cleanup_policy] is in effect.
        This setting is helpful if you need to control the size of a log due to limited disk space.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.retention_bytes] setting.
        """

    @property
    def log_retention_hours(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of hours to keep a log segment file before deleting it."""

    @property
    def log_retention_minutes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of minutes to keep a log segment file before deleting it.

        If not set, the value of [log_retention_hours] is used.
        """

    @property
    def log_retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of milliseconds to keep a log segment file before deleting it.

        If not set, the value of [log_retention_minutes] is used.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.retention_ms] setting.
        """

    @property
    def log_segment_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size of a single log file.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.segment_bytes] setting.
        """

    @property
    def log_preallocate(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Should pre allocate file when create new segment?

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig2_8.preallocate] setting.
        """

    @property
    def socket_send_buffer_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The SO_SNDBUF buffer of the socket server sockets. If the value is -1, the OS default will be used."""

    @property
    def socket_receive_buffer_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The SO_RCVBUF buffer of the socket server sockets. If the value is -1, the OS default will be used."""

    @property
    def auto_create_topics_enable(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable auto creation of topic on the server"""

    @property
    def num_partitions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Default number of partitions per topic on the whole cluster"""

    @property
    def default_replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Default replication factor of the topic on the whole cluster"""

    @property
    def message_max_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The largest record batch size allowed by Kafka. Default value: 1048588."""

    @property
    def replica_fetch_max_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of bytes of messages to attempt to fetch for each partition. Default value: 1048576."""

    @property
    def ssl_cipher_suites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of cipher suites."""

    @property
    def offsets_retention_minutes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Offset storage time after a consumer group loses all its consumers. Default: 10080."""

    @property
    def sasl_enabled_mechanisms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.mdb.kafka.v1.common_pb2.SaslMechanism.ValueType]:
        """The list of SASL mechanisms enabled in the Kafka server. Default: [SCRAM_SHA_512]."""

    def __init__(
        self,
        *,
        compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType = ...,
        log_flush_interval_messages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_flush_interval_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_flush_scheduler_interval_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_hours: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_minutes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_segment_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_preallocate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        socket_send_buffer_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        socket_receive_buffer_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_create_topics_enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        num_partitions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        message_max_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        replica_fetch_max_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ssl_cipher_suites: collections.abc.Iterable[builtins.str] | None = ...,
        offsets_retention_minutes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        sasl_enabled_mechanisms: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.common_pb2.SaslMechanism.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_create_topics_enable", b"auto_create_topics_enable", "default_replication_factor", b"default_replication_factor", "log_flush_interval_messages", b"log_flush_interval_messages", "log_flush_interval_ms", b"log_flush_interval_ms", "log_flush_scheduler_interval_ms", b"log_flush_scheduler_interval_ms", "log_preallocate", b"log_preallocate", "log_retention_bytes", b"log_retention_bytes", "log_retention_hours", b"log_retention_hours", "log_retention_minutes", b"log_retention_minutes", "log_retention_ms", b"log_retention_ms", "log_segment_bytes", b"log_segment_bytes", "message_max_bytes", b"message_max_bytes", "num_partitions", b"num_partitions", "offsets_retention_minutes", b"offsets_retention_minutes", "replica_fetch_max_bytes", b"replica_fetch_max_bytes", "socket_receive_buffer_bytes", b"socket_receive_buffer_bytes", "socket_send_buffer_bytes", b"socket_send_buffer_bytes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_create_topics_enable", b"auto_create_topics_enable", "compression_type", b"compression_type", "default_replication_factor", b"default_replication_factor", "log_flush_interval_messages", b"log_flush_interval_messages", "log_flush_interval_ms", b"log_flush_interval_ms", "log_flush_scheduler_interval_ms", b"log_flush_scheduler_interval_ms", "log_preallocate", b"log_preallocate", "log_retention_bytes", b"log_retention_bytes", "log_retention_hours", b"log_retention_hours", "log_retention_minutes", b"log_retention_minutes", "log_retention_ms", b"log_retention_ms", "log_segment_bytes", b"log_segment_bytes", "message_max_bytes", b"message_max_bytes", "num_partitions", b"num_partitions", "offsets_retention_minutes", b"offsets_retention_minutes", "replica_fetch_max_bytes", b"replica_fetch_max_bytes", "sasl_enabled_mechanisms", b"sasl_enabled_mechanisms", "socket_receive_buffer_bytes", b"socket_receive_buffer_bytes", "socket_send_buffer_bytes", b"socket_send_buffer_bytes", "ssl_cipher_suites", b"ssl_cipher_suites"]) -> None: ...

global___KafkaConfig2_8 = KafkaConfig2_8

@typing.final
class KafkaConfig3(google.protobuf.message.Message):
    """Kafka version 3.x broker configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    LOG_FLUSH_INTERVAL_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_FLUSH_INTERVAL_MS_FIELD_NUMBER: builtins.int
    LOG_FLUSH_SCHEDULER_INTERVAL_MS_FIELD_NUMBER: builtins.int
    LOG_RETENTION_BYTES_FIELD_NUMBER: builtins.int
    LOG_RETENTION_HOURS_FIELD_NUMBER: builtins.int
    LOG_RETENTION_MINUTES_FIELD_NUMBER: builtins.int
    LOG_RETENTION_MS_FIELD_NUMBER: builtins.int
    LOG_SEGMENT_BYTES_FIELD_NUMBER: builtins.int
    LOG_PREALLOCATE_FIELD_NUMBER: builtins.int
    SOCKET_SEND_BUFFER_BYTES_FIELD_NUMBER: builtins.int
    SOCKET_RECEIVE_BUFFER_BYTES_FIELD_NUMBER: builtins.int
    AUTO_CREATE_TOPICS_ENABLE_FIELD_NUMBER: builtins.int
    NUM_PARTITIONS_FIELD_NUMBER: builtins.int
    DEFAULT_REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    MESSAGE_MAX_BYTES_FIELD_NUMBER: builtins.int
    REPLICA_FETCH_MAX_BYTES_FIELD_NUMBER: builtins.int
    SSL_CIPHER_SUITES_FIELD_NUMBER: builtins.int
    OFFSETS_RETENTION_MINUTES_FIELD_NUMBER: builtins.int
    SASL_ENABLED_MECHANISMS_FIELD_NUMBER: builtins.int
    compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType
    """Cluster topics compression type."""
    @property
    def log_flush_interval_messages(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of messages accumulated on a log partition before messages are flushed to disk.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.flush_messages] setting.
        """

    @property
    def log_flush_interval_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time (in milliseconds) that a message in any topic is kept in memory before flushed to disk.
        If not set, the value of [log_flush_scheduler_interval_ms] is used.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.flush_ms] setting.
        """

    @property
    def log_flush_scheduler_interval_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The frequency of checks (in milliseconds) for any logs that need to be flushed to disk.
        This check is done by the log flusher.
        """

    @property
    def log_retention_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Partition size limit; Kafka will discard old log segments to free up space if `delete` [TopicConfig3.cleanup_policy] is in effect.
        This setting is helpful if you need to control the size of a log due to limited disk space.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.retention_bytes] setting.
        """

    @property
    def log_retention_hours(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of hours to keep a log segment file before deleting it."""

    @property
    def log_retention_minutes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of minutes to keep a log segment file before deleting it.

        If not set, the value of [log_retention_hours] is used.
        """

    @property
    def log_retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of milliseconds to keep a log segment file before deleting it.

        If not set, the value of [log_retention_minutes] is used.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.retention_ms] setting.
        """

    @property
    def log_segment_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size of a single log file.

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.segment_bytes] setting.
        """

    @property
    def log_preallocate(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Should pre allocate file when create new segment?

        This is the global cluster-level setting that can be overridden on a topic level by using the [TopicConfig3.preallocate] setting.
        """

    @property
    def socket_send_buffer_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The SO_SNDBUF buffer of the socket server sockets. If the value is -1, the OS default will be used."""

    @property
    def socket_receive_buffer_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The SO_RCVBUF buffer of the socket server sockets. If the value is -1, the OS default will be used."""

    @property
    def auto_create_topics_enable(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable auto creation of topic on the server"""

    @property
    def num_partitions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Default number of partitions per topic on the whole cluster"""

    @property
    def default_replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Default replication factor of the topic on the whole cluster"""

    @property
    def message_max_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The largest record batch size allowed by Kafka. Default value: 1048588."""

    @property
    def replica_fetch_max_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of bytes of messages to attempt to fetch for each partition. Default value: 1048576."""

    @property
    def ssl_cipher_suites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of cipher suites."""

    @property
    def offsets_retention_minutes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Offset storage time after a consumer group loses all its consumers. Default: 10080."""

    @property
    def sasl_enabled_mechanisms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.mdb.kafka.v1.common_pb2.SaslMechanism.ValueType]:
        """The list of SASL mechanisms enabled in the Kafka server. Default: [SCRAM_SHA_512]."""

    def __init__(
        self,
        *,
        compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType = ...,
        log_flush_interval_messages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_flush_interval_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_flush_scheduler_interval_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_hours: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_minutes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_segment_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_preallocate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        socket_send_buffer_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        socket_receive_buffer_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_create_topics_enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        num_partitions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        default_replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        message_max_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        replica_fetch_max_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ssl_cipher_suites: collections.abc.Iterable[builtins.str] | None = ...,
        offsets_retention_minutes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        sasl_enabled_mechanisms: collections.abc.Iterable[yandex.cloud.mdb.kafka.v1.common_pb2.SaslMechanism.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_create_topics_enable", b"auto_create_topics_enable", "default_replication_factor", b"default_replication_factor", "log_flush_interval_messages", b"log_flush_interval_messages", "log_flush_interval_ms", b"log_flush_interval_ms", "log_flush_scheduler_interval_ms", b"log_flush_scheduler_interval_ms", "log_preallocate", b"log_preallocate", "log_retention_bytes", b"log_retention_bytes", "log_retention_hours", b"log_retention_hours", "log_retention_minutes", b"log_retention_minutes", "log_retention_ms", b"log_retention_ms", "log_segment_bytes", b"log_segment_bytes", "message_max_bytes", b"message_max_bytes", "num_partitions", b"num_partitions", "offsets_retention_minutes", b"offsets_retention_minutes", "replica_fetch_max_bytes", b"replica_fetch_max_bytes", "socket_receive_buffer_bytes", b"socket_receive_buffer_bytes", "socket_send_buffer_bytes", b"socket_send_buffer_bytes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_create_topics_enable", b"auto_create_topics_enable", "compression_type", b"compression_type", "default_replication_factor", b"default_replication_factor", "log_flush_interval_messages", b"log_flush_interval_messages", "log_flush_interval_ms", b"log_flush_interval_ms", "log_flush_scheduler_interval_ms", b"log_flush_scheduler_interval_ms", "log_preallocate", b"log_preallocate", "log_retention_bytes", b"log_retention_bytes", "log_retention_hours", b"log_retention_hours", "log_retention_minutes", b"log_retention_minutes", "log_retention_ms", b"log_retention_ms", "log_segment_bytes", b"log_segment_bytes", "message_max_bytes", b"message_max_bytes", "num_partitions", b"num_partitions", "offsets_retention_minutes", b"offsets_retention_minutes", "replica_fetch_max_bytes", b"replica_fetch_max_bytes", "sasl_enabled_mechanisms", b"sasl_enabled_mechanisms", "socket_receive_buffer_bytes", b"socket_receive_buffer_bytes", "socket_send_buffer_bytes", b"socket_send_buffer_bytes", "ssl_cipher_suites", b"ssl_cipher_suites"]) -> None: ...

global___KafkaConfig3 = KafkaConfig3

@typing.final
class Host(google.protobuf.message.Message):
    """Cluster host metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNSPECIFIED: Host._Role.ValueType  # 0
        """Role of the host is unspecified. Default value."""
        KAFKA: Host._Role.ValueType  # 1
        """The host is a Kafka broker."""
        ZOOKEEPER: Host._Role.ValueType  # 2
        """The host is a ZooKeeper server."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
    ROLE_UNSPECIFIED: Host.Role.ValueType  # 0
    """Role of the host is unspecified. Default value."""
    KAFKA: Host.Role.ValueType  # 1
    """The host is a Kafka broker."""
    ZOOKEEPER: Host.Role.ValueType  # 2
    """The host is a ZooKeeper server."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown. Default value."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded and can perform only some of its essential functions."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown. Default value."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded and can perform only some of its essential functions."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the host."""
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster."""
    zone_id: builtins.str
    """ID of the availability zone where the host resides."""
    role: global___Host.Role.ValueType
    """Host role. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated host health data. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet the host resides in."""
    assign_public_ip: builtins.bool
    """The flag that defines whether a public IP address is assigned to the node.

    If the value is `true`, then this node is available on the Internet via it's public IP address.
    """
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        role: global___Host.Role.ValueType = ...,
        resources: global___Resources | None = ...,
        health: global___Host.Health.ValueType = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "role", b"role", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    data_transfer: builtins.bool
    """Allow access for DataTransfer."""
    def __init__(
        self,
        *,
        data_transfer: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_transfer", b"data_transfer"]) -> None: ...

global___Access = Access

@typing.final
class DiskSizeAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLANNED_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    EMERGENCY_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    DISK_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    planned_usage_threshold: builtins.int
    """Threshold of storage usage (in percent) that triggers automatic scaling of the storage during the maintenance window. Zero value means disabled threshold."""
    emergency_usage_threshold: builtins.int
    """Threshold of storage usage (in percent) that triggers immediate automatic scaling of the storage. Zero value means disabled threshold."""
    disk_size_limit: builtins.int
    """New storage size (in bytes) that is set when one of the thresholds is achieved."""
    def __init__(
        self,
        *,
        planned_usage_threshold: builtins.int = ...,
        emergency_usage_threshold: builtins.int = ...,
        disk_size_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size_limit", b"disk_size_limit", "emergency_usage_threshold", b"emergency_usage_threshold", "planned_usage_threshold", b"planned_usage_threshold"]) -> None: ...

global___DiskSizeAutoscaling = DiskSizeAutoscaling



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserSshKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    subject_id: builtins.str
    data: builtins.str
    name: builtins.str
    fingerprint: builtins.str
    organization_id: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Used for temporary keys, if empty the key doesn't expire"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        subject_id: builtins.str = ...,
        data: builtins.str = ...,
        name: builtins.str = ...,
        fingerprint: builtins.str = ...,
        organization_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "data", b"data", "expires_at", b"expires_at", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "organization_id", b"organization_id", "subject_id", b"subject_id"]) -> None: ...

global___UserSshKey = UserSshKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.smartcaptcha.v1.captcha_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetCaptchaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the Captcha resource to return."""
    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id"]) -> None: ...

global___GetCaptchaRequest = GetCaptchaRequest

@typing.final
class ListCaptchasRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the captcha belongs to.
    Currently page_size, page_token, filter and order_by are not supported and List method will return all captchas in the folder.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListCaptchasRequest = ListCaptchasRequest

@typing.final
class ListCaptchasResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartcaptcha.v1.captcha_pb2.Captcha]:
        """List of Captcha resources.
        Currently next_page_token is not supported and List method will return all captchas in the folder.
        """

    def __init__(
        self,
        *,
        resources: collections.abc.Iterable[yandex.cloud.smartcaptcha.v1.captcha_pb2.Captcha] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___ListCaptchasResponse = ListCaptchasResponse

@typing.final
class CreateCaptchaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_SITES_FIELD_NUMBER: builtins.int
    COMPLEXITY_FIELD_NUMBER: builtins.int
    STYLE_JSON_FIELD_NUMBER: builtins.int
    TURN_OFF_HOSTNAME_CHECK_FIELD_NUMBER: builtins.int
    PRE_CHECK_TYPE_FIELD_NUMBER: builtins.int
    CHALLENGE_TYPE_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    OVERRIDE_VARIANTS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a captcha in."""
    name: builtins.str
    """Name of the captcha.
    The name must be unique within the folder.
    """
    complexity: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaComplexity.ValueType
    """Complexity of the captcha."""
    style_json: builtins.str
    """JSON with variables to define the captcha appearance. For more details see generated JSON in cloud console."""
    turn_off_hostname_check: builtins.bool
    """Turn off host name check, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""
    pre_check_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaPreCheckType.ValueType
    """Basic check type of the captcha."""
    challenge_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaChallengeType.ValueType
    """Additional task type of the captcha."""
    deletion_protection: builtins.bool
    """Determines whether captcha is protected from being deleted."""
    @property
    def allowed_sites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of allowed host names, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartcaptcha.v1.captcha_pb2.SecurityRule]:
        """List of security rules."""

    @property
    def override_variants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartcaptcha.v1.captcha_pb2.OverrideVariant]:
        """List of variants to use in security_rules"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        allowed_sites: collections.abc.Iterable[builtins.str] | None = ...,
        complexity: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaComplexity.ValueType = ...,
        style_json: builtins.str = ...,
        turn_off_hostname_check: builtins.bool = ...,
        pre_check_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaPreCheckType.ValueType = ...,
        challenge_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaChallengeType.ValueType = ...,
        security_rules: collections.abc.Iterable[yandex.cloud.smartcaptcha.v1.captcha_pb2.SecurityRule] | None = ...,
        deletion_protection: builtins.bool = ...,
        override_variants: collections.abc.Iterable[yandex.cloud.smartcaptcha.v1.captcha_pb2.OverrideVariant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allowed_sites", b"allowed_sites", "challenge_type", b"challenge_type", "complexity", b"complexity", "deletion_protection", b"deletion_protection", "folder_id", b"folder_id", "name", b"name", "override_variants", b"override_variants", "pre_check_type", b"pre_check_type", "security_rules", b"security_rules", "style_json", b"style_json", "turn_off_hostname_check", b"turn_off_hostname_check"]) -> None: ...

global___CreateCaptchaRequest = CreateCaptchaRequest

@typing.final
class CreateCaptchaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the captcha that is being created."""
    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id"]) -> None: ...

global___CreateCaptchaMetadata = CreateCaptchaMetadata

@typing.final
class DeleteCaptchaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the captcha to delete."""
    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id"]) -> None: ...

global___DeleteCaptchaRequest = DeleteCaptchaRequest

@typing.final
class DeleteCaptchaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the Captcha resource that is being deleted."""
    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id"]) -> None: ...

global___DeleteCaptchaMetadata = DeleteCaptchaMetadata

@typing.final
class UpdateCaptchaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_SITES_FIELD_NUMBER: builtins.int
    COMPLEXITY_FIELD_NUMBER: builtins.int
    STYLE_JSON_FIELD_NUMBER: builtins.int
    TURN_OFF_HOSTNAME_CHECK_FIELD_NUMBER: builtins.int
    PRE_CHECK_TYPE_FIELD_NUMBER: builtins.int
    CHALLENGE_TYPE_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    OVERRIDE_VARIANTS_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the captcha to update."""
    name: builtins.str
    """Name of the captcha.
    The name must be unique within the folder.
    """
    complexity: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaComplexity.ValueType
    """Complexity of the captcha."""
    style_json: builtins.str
    """JSON with variables to define the captcha appearance. For more details see generated JSON in cloud console."""
    turn_off_hostname_check: builtins.bool
    """Turn off host name check, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""
    pre_check_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaPreCheckType.ValueType
    """Basic check type of the captcha."""
    challenge_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaChallengeType.ValueType
    """Additional task type of the captcha."""
    deletion_protection: builtins.bool
    """Determines whether captcha is protected from being deleted."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Captcha resource are going to be updated."""

    @property
    def allowed_sites(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of allowed host names, see [Domain validation](/docs/smartcaptcha/concepts/domain-validation)."""

    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartcaptcha.v1.captcha_pb2.SecurityRule]:
        """List of security rules."""

    @property
    def override_variants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartcaptcha.v1.captcha_pb2.OverrideVariant]:
        """List of variants to use in security_rules"""

    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        allowed_sites: collections.abc.Iterable[builtins.str] | None = ...,
        complexity: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaComplexity.ValueType = ...,
        style_json: builtins.str = ...,
        turn_off_hostname_check: builtins.bool = ...,
        pre_check_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaPreCheckType.ValueType = ...,
        challenge_type: yandex.cloud.smartcaptcha.v1.captcha_pb2.CaptchaChallengeType.ValueType = ...,
        security_rules: collections.abc.Iterable[yandex.cloud.smartcaptcha.v1.captcha_pb2.SecurityRule] | None = ...,
        deletion_protection: builtins.bool = ...,
        override_variants: collections.abc.Iterable[yandex.cloud.smartcaptcha.v1.captcha_pb2.OverrideVariant] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowed_sites", b"allowed_sites", "captcha_id", b"captcha_id", "challenge_type", b"challenge_type", "complexity", b"complexity", "deletion_protection", b"deletion_protection", "name", b"name", "override_variants", b"override_variants", "pre_check_type", b"pre_check_type", "security_rules", b"security_rules", "style_json", b"style_json", "turn_off_hostname_check", b"turn_off_hostname_check", "update_mask", b"update_mask"]) -> None: ...

global___UpdateCaptchaRequest = UpdateCaptchaRequest

@typing.final
class UpdateCaptchaMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPTCHA_ID_FIELD_NUMBER: builtins.int
    captcha_id: builtins.str
    """ID of the Captcha resource that is being updated."""
    def __init__(
        self,
        *,
        captcha_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["captcha_id", b"captcha_id"]) -> None: ...

global___UpdateCaptchaMetadata = UpdateCaptchaMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MongodConfig3_6(google.protobuf.message.Message):
    """Configuration of a mongod daemon. Supported options are a limited subset of all
    options described in [MongoDB documentation](https://docs.mongodb.com/v3.6/reference/configuration-options/).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Storage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class WiredTiger(google.protobuf.message.Message):
            """Configuration of WiredTiger storage engine."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class EngineConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                CACHE_SIZE_GB_FIELD_NUMBER: builtins.int
                @property
                def cache_size_gb(self) -> google.protobuf.wrappers_pb2.DoubleValue:
                    """The maximum size of the internal cache that WiredTiger will use for all data."""

                def __init__(
                    self,
                    *,
                    cache_size_gb: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> None: ...

            @typing.final
            class CollectionConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Compressor:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _CompressorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongodConfig3_6.Storage.WiredTiger.CollectionConfig._Compressor.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    COMPRESSOR_UNSPECIFIED: MongodConfig3_6.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 0
                    NONE: MongodConfig3_6.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 1
                    """No compression."""
                    SNAPPY: MongodConfig3_6.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 2
                    """The [Snappy](https://docs.mongodb.com/v3.6/reference/glossary/#term-snappy) compression."""
                    ZLIB: MongodConfig3_6.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 3
                    """The [zlib](https://docs.mongodb.com/v3.6/reference/glossary/#term-zlib) compression."""

                class Compressor(_Compressor, metaclass=_CompressorEnumTypeWrapper): ...
                COMPRESSOR_UNSPECIFIED: MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 0
                NONE: MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 1
                """No compression."""
                SNAPPY: MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 2
                """The [Snappy](https://docs.mongodb.com/v3.6/reference/glossary/#term-snappy) compression."""
                ZLIB: MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 3
                """The [zlib](https://docs.mongodb.com/v3.6/reference/glossary/#term-zlib) compression."""

                BLOCK_COMPRESSOR_FIELD_NUMBER: builtins.int
                block_compressor: global___MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType
                """Default type of compression to use for collection data."""
                def __init__(
                    self,
                    *,
                    block_compressor: global___MongodConfig3_6.Storage.WiredTiger.CollectionConfig.Compressor.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["block_compressor", b"block_compressor"]) -> None: ...

            ENGINE_CONFIG_FIELD_NUMBER: builtins.int
            COLLECTION_CONFIG_FIELD_NUMBER: builtins.int
            @property
            def engine_config(self) -> global___MongodConfig3_6.Storage.WiredTiger.EngineConfig:
                """Engine configuration for WiredTiger."""

            @property
            def collection_config(self) -> global___MongodConfig3_6.Storage.WiredTiger.CollectionConfig:
                """Collection configuration for WiredTiger."""

            def __init__(
                self,
                *,
                engine_config: global___MongodConfig3_6.Storage.WiredTiger.EngineConfig | None = ...,
                collection_config: global___MongodConfig3_6.Storage.WiredTiger.CollectionConfig | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["collection_config", b"collection_config", "engine_config", b"engine_config"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["collection_config", b"collection_config", "engine_config", b"engine_config"]) -> None: ...

        @typing.final
        class Journal(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ENABLED_FIELD_NUMBER: builtins.int
            COMMIT_INTERVAL_FIELD_NUMBER: builtins.int
            @property
            def enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
                """Whether the journal is enabled or disabled.
                Possible values:
                * true (default) - the journal is enabled.
                * false - the journal is disabled.
                """

            @property
            def commit_interval(self) -> google.protobuf.wrappers_pb2.Int64Value:
                """Commit interval between journal operations, in milliseconds.
                Default: 100.
                """

            def __init__(
                self,
                *,
                enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
                commit_interval: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["commit_interval", b"commit_interval", "enabled", b"enabled"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["commit_interval", b"commit_interval", "enabled", b"enabled"]) -> None: ...

        WIRED_TIGER_FIELD_NUMBER: builtins.int
        JOURNAL_FIELD_NUMBER: builtins.int
        @property
        def wired_tiger(self) -> global___MongodConfig3_6.Storage.WiredTiger:
            """Configuration of the WiredTiger storage engine."""

        @property
        def journal(self) -> global___MongodConfig3_6.Storage.Journal:
            """Configuration of the MongoDB [journal](https://docs.mongodb.com/v3.6/reference/glossary/#term-journal)."""

        def __init__(
            self,
            *,
            wired_tiger: global___MongodConfig3_6.Storage.WiredTiger | None = ...,
            journal: global___MongodConfig3_6.Storage.Journal | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["journal", b"journal", "wired_tiger", b"wired_tiger"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["journal", b"journal", "wired_tiger", b"wired_tiger"]) -> None: ...

    @typing.final
    class OperationProfiling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongodConfig3_6.OperationProfiling._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: MongodConfig3_6.OperationProfiling._Mode.ValueType  # 0
            OFF: MongodConfig3_6.OperationProfiling._Mode.ValueType  # 1
            """The profiler is off and does not collect any data."""
            SLOW_OP: MongodConfig3_6.OperationProfiling._Mode.ValueType  # 2
            """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
            ALL: MongodConfig3_6.OperationProfiling._Mode.ValueType  # 3
            """The profiler collects data for all operations."""

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        MODE_UNSPECIFIED: MongodConfig3_6.OperationProfiling.Mode.ValueType  # 0
        OFF: MongodConfig3_6.OperationProfiling.Mode.ValueType  # 1
        """The profiler is off and does not collect any data."""
        SLOW_OP: MongodConfig3_6.OperationProfiling.Mode.ValueType  # 2
        """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
        ALL: MongodConfig3_6.OperationProfiling.Mode.ValueType  # 3
        """The profiler collects data for all operations."""

        MODE_FIELD_NUMBER: builtins.int
        SLOW_OP_THRESHOLD_FIELD_NUMBER: builtins.int
        mode: global___MongodConfig3_6.OperationProfiling.Mode.ValueType
        """Mode which specifies operations that should be profiled."""
        @property
        def slow_op_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The slow operation time threshold, in milliseconds. Operations that run
            for longer than this threshold are considered slow, and are processed by the profiler
            running in the SLOW_OP mode.
            """

        def __init__(
            self,
            *,
            mode: global___MongodConfig3_6.OperationProfiling.Mode.ValueType = ...,
            slow_op_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["slow_op_threshold", b"slow_op_threshold"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode", "slow_op_threshold", b"slow_op_threshold"]) -> None: ...

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of simultaneous connections that mongod will accept."""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    STORAGE_FIELD_NUMBER: builtins.int
    OPERATION_PROFILING_FIELD_NUMBER: builtins.int
    NET_FIELD_NUMBER: builtins.int
    @property
    def storage(self) -> global___MongodConfig3_6.Storage:
        """`storage` section of mongod configuration."""

    @property
    def operation_profiling(self) -> global___MongodConfig3_6.OperationProfiling:
        """`operationProfiling` section of mongod configuration."""

    @property
    def net(self) -> global___MongodConfig3_6.Network:
        """`net` section of mongod configuration."""

    def __init__(
        self,
        *,
        storage: global___MongodConfig3_6.Storage | None = ...,
        operation_profiling: global___MongodConfig3_6.OperationProfiling | None = ...,
        net: global___MongodConfig3_6.Network | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> None: ...

global___MongodConfig3_6 = MongodConfig3_6

@typing.final
class MongoCfgConfig3_6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Storage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class WiredTiger(google.protobuf.message.Message):
            """Configuration of WiredTiger storage engine."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class EngineConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                CACHE_SIZE_GB_FIELD_NUMBER: builtins.int
                @property
                def cache_size_gb(self) -> google.protobuf.wrappers_pb2.DoubleValue:
                    """The maximum size of the internal cache that WiredTiger will use for all data."""

                def __init__(
                    self,
                    *,
                    cache_size_gb: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> None: ...

            ENGINE_CONFIG_FIELD_NUMBER: builtins.int
            @property
            def engine_config(self) -> global___MongoCfgConfig3_6.Storage.WiredTiger.EngineConfig:
                """Engine configuration for WiredTiger."""

            def __init__(
                self,
                *,
                engine_config: global___MongoCfgConfig3_6.Storage.WiredTiger.EngineConfig | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["engine_config", b"engine_config"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["engine_config", b"engine_config"]) -> None: ...

        WIRED_TIGER_FIELD_NUMBER: builtins.int
        @property
        def wired_tiger(self) -> global___MongoCfgConfig3_6.Storage.WiredTiger:
            """Configuration of the WiredTiger storage engine."""

        def __init__(
            self,
            *,
            wired_tiger: global___MongoCfgConfig3_6.Storage.WiredTiger | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["wired_tiger", b"wired_tiger"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["wired_tiger", b"wired_tiger"]) -> None: ...

    @typing.final
    class OperationProfiling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongoCfgConfig3_6.OperationProfiling._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: MongoCfgConfig3_6.OperationProfiling._Mode.ValueType  # 0
            OFF: MongoCfgConfig3_6.OperationProfiling._Mode.ValueType  # 1
            """The profiler is off and does not collect any data. This is the default
            profiler level.
            """
            SLOW_OP: MongoCfgConfig3_6.OperationProfiling._Mode.ValueType  # 2
            """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
            ALL: MongoCfgConfig3_6.OperationProfiling._Mode.ValueType  # 3
            """The profiler collects data for all operations."""

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        MODE_UNSPECIFIED: MongoCfgConfig3_6.OperationProfiling.Mode.ValueType  # 0
        OFF: MongoCfgConfig3_6.OperationProfiling.Mode.ValueType  # 1
        """The profiler is off and does not collect any data. This is the default
        profiler level.
        """
        SLOW_OP: MongoCfgConfig3_6.OperationProfiling.Mode.ValueType  # 2
        """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
        ALL: MongoCfgConfig3_6.OperationProfiling.Mode.ValueType  # 3
        """The profiler collects data for all operations."""

        MODE_FIELD_NUMBER: builtins.int
        SLOW_OP_THRESHOLD_FIELD_NUMBER: builtins.int
        mode: global___MongoCfgConfig3_6.OperationProfiling.Mode.ValueType
        """Operation profiling level. For details, see [MongoDB documentation](https://docs.mongodb.com/v3.6/tutorial/manage-the-database-profiler/)."""
        @property
        def slow_op_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The slow operation time threshold, in milliseconds. Operations that run
            for longer than this threshold are considered slow, and are processed by the profiler
            running in the SLOW_OP mode. For details see [MongoDB documentation](https://docs.mongodb.com/v3.6/reference/configuration-options/#operationProfiling.slowOpThresholdMs).
            """

        def __init__(
            self,
            *,
            mode: global___MongoCfgConfig3_6.OperationProfiling.Mode.ValueType = ...,
            slow_op_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["slow_op_threshold", b"slow_op_threshold"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode", "slow_op_threshold", b"slow_op_threshold"]) -> None: ...

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of incoming connections."""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    STORAGE_FIELD_NUMBER: builtins.int
    OPERATION_PROFILING_FIELD_NUMBER: builtins.int
    NET_FIELD_NUMBER: builtins.int
    @property
    def storage(self) -> global___MongoCfgConfig3_6.Storage:
        """`storage` section of mongocfg configuration."""

    @property
    def operation_profiling(self) -> global___MongoCfgConfig3_6.OperationProfiling:
        """`operationProfiling` section of mongocfg configuration."""

    @property
    def net(self) -> global___MongoCfgConfig3_6.Network:
        """`net` section of mongocfg configuration."""

    def __init__(
        self,
        *,
        storage: global___MongoCfgConfig3_6.Storage | None = ...,
        operation_profiling: global___MongoCfgConfig3_6.OperationProfiling | None = ...,
        net: global___MongoCfgConfig3_6.Network | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> None: ...

global___MongoCfgConfig3_6 = MongoCfgConfig3_6

@typing.final
class MongosConfig3_6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of incoming connections."""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    NET_FIELD_NUMBER: builtins.int
    @property
    def net(self) -> global___MongosConfig3_6.Network:
        """Network settings for mongos."""

    def __init__(
        self,
        *,
        net: global___MongosConfig3_6.Network | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net"]) -> None: ...

global___MongosConfig3_6 = MongosConfig3_6

@typing.final
class MongodConfigSet3_6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongodConfig3_6:
        """Effective mongod settings for a MongoDB 3.6 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongodConfig3_6:
        """User-defined mongod settings for a MongoDB 3.6 cluster."""

    @property
    def default_config(self) -> global___MongodConfig3_6:
        """Default mongod configuration for a MongoDB 3.6 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongodConfig3_6 | None = ...,
        user_config: global___MongodConfig3_6 | None = ...,
        default_config: global___MongodConfig3_6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongodConfigSet3_6 = MongodConfigSet3_6

@typing.final
class MongoCfgConfigSet3_6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongoCfgConfig3_6:
        """Effective mongocfg settings for a MongoDB 3.6 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongoCfgConfig3_6:
        """User-defined mongocfg settings for a MongoDB 3.6 cluster."""

    @property
    def default_config(self) -> global___MongoCfgConfig3_6:
        """Default mongocfg configuration for a MongoDB 3.6 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongoCfgConfig3_6 | None = ...,
        user_config: global___MongoCfgConfig3_6 | None = ...,
        default_config: global___MongoCfgConfig3_6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongoCfgConfigSet3_6 = MongoCfgConfigSet3_6

@typing.final
class MongosConfigSet3_6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongosConfig3_6:
        """Effective settings for a MongoDB 3.6 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongosConfig3_6:
        """User-defined settings for a MongoDB 3.6 cluster."""

    @property
    def default_config(self) -> global___MongosConfig3_6:
        """Default configuration for a MongoDB 3.6 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongosConfig3_6 | None = ...,
        user_config: global___MongosConfig3_6 | None = ...,
        default_config: global___MongosConfig3_6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongosConfigSet3_6 = MongosConfigSet3_6



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.cache_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CacheServiceStub:
    """A set of methods for managing Cache Service resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Purge: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.cache_service_pb2.PurgeCacheRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified files from the cache of the specified resource. For details about purging, see [documentation](/docs/cdn/concepts/caching#purge).

    Purging may take up to 15 minutes.
    """

    Prefetch: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.cache_service_pb2.PrefetchCacheRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Uploads specified files from origins to cache of the specified resource. For defails about prefetching, see [documentation](/docs/cdn/concepts/caching#prefetch)."""

class CacheServiceAsyncStub:
    """A set of methods for managing Cache Service resources."""

    Purge: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.cache_service_pb2.PurgeCacheRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified files from the cache of the specified resource. For details about purging, see [documentation](/docs/cdn/concepts/caching#purge).

    Purging may take up to 15 minutes.
    """

    Prefetch: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.cache_service_pb2.PrefetchCacheRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Uploads specified files from origins to cache of the specified resource. For defails about prefetching, see [documentation](/docs/cdn/concepts/caching#prefetch)."""

class CacheServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Cache Service resources."""

    @abc.abstractmethod
    def Purge(
        self,
        request: yandex.cloud.cdn.v1.cache_service_pb2.PurgeCacheRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified files from the cache of the specified resource. For details about purging, see [documentation](/docs/cdn/concepts/caching#purge).

        Purging may take up to 15 minutes.
        """

    @abc.abstractmethod
    def Prefetch(
        self,
        request: yandex.cloud.cdn.v1.cache_service_pb2.PrefetchCacheRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Uploads specified files from origins to cache of the specified resource. For defails about prefetching, see [documentation](/docs/cdn/concepts/caching#prefetch)."""

def add_CacheServiceServicer_to_server(servicer: CacheServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PostgresqlHostConfig16(google.protobuf.message.Message):
    """Options and structure of `PostgresqlConfig` reflects PostgreSQL configuration file
    parameters which detailed description is available in
    [PostgreSQL documentation](https://www.postgresql.org/docs/11/runtime-config.html).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackslashQuote:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackslashQuoteEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._BackslashQuote.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlHostConfig16._BackslashQuote.ValueType  # 0
        BACKSLASH_QUOTE: PostgresqlHostConfig16._BackslashQuote.ValueType  # 1
        BACKSLASH_QUOTE_ON: PostgresqlHostConfig16._BackslashQuote.ValueType  # 2
        BACKSLASH_QUOTE_OFF: PostgresqlHostConfig16._BackslashQuote.ValueType  # 3
        BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlHostConfig16._BackslashQuote.ValueType  # 4

    class BackslashQuote(_BackslashQuote, metaclass=_BackslashQuoteEnumTypeWrapper): ...
    BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlHostConfig16.BackslashQuote.ValueType  # 0
    BACKSLASH_QUOTE: PostgresqlHostConfig16.BackslashQuote.ValueType  # 1
    BACKSLASH_QUOTE_ON: PostgresqlHostConfig16.BackslashQuote.ValueType  # 2
    BACKSLASH_QUOTE_OFF: PostgresqlHostConfig16.BackslashQuote.ValueType  # 3
    BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlHostConfig16.BackslashQuote.ValueType  # 4

    class _ByteaOutput:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ByteaOutputEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._ByteaOutput.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BYTEA_OUTPUT_UNSPECIFIED: PostgresqlHostConfig16._ByteaOutput.ValueType  # 0
        BYTEA_OUTPUT_HEX: PostgresqlHostConfig16._ByteaOutput.ValueType  # 1
        BYTEA_OUTPUT_ESCAPED: PostgresqlHostConfig16._ByteaOutput.ValueType  # 2

    class ByteaOutput(_ByteaOutput, metaclass=_ByteaOutputEnumTypeWrapper): ...
    BYTEA_OUTPUT_UNSPECIFIED: PostgresqlHostConfig16.ByteaOutput.ValueType  # 0
    BYTEA_OUTPUT_HEX: PostgresqlHostConfig16.ByteaOutput.ValueType  # 1
    BYTEA_OUTPUT_ESCAPED: PostgresqlHostConfig16.ByteaOutput.ValueType  # 2

    class _ConstraintExclusion:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConstraintExclusionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._ConstraintExclusion.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlHostConfig16._ConstraintExclusion.ValueType  # 0
        CONSTRAINT_EXCLUSION_ON: PostgresqlHostConfig16._ConstraintExclusion.ValueType  # 1
        CONSTRAINT_EXCLUSION_OFF: PostgresqlHostConfig16._ConstraintExclusion.ValueType  # 2
        CONSTRAINT_EXCLUSION_PARTITION: PostgresqlHostConfig16._ConstraintExclusion.ValueType  # 3

    class ConstraintExclusion(_ConstraintExclusion, metaclass=_ConstraintExclusionEnumTypeWrapper): ...
    CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlHostConfig16.ConstraintExclusion.ValueType  # 0
    CONSTRAINT_EXCLUSION_ON: PostgresqlHostConfig16.ConstraintExclusion.ValueType  # 1
    CONSTRAINT_EXCLUSION_OFF: PostgresqlHostConfig16.ConstraintExclusion.ValueType  # 2
    CONSTRAINT_EXCLUSION_PARTITION: PostgresqlHostConfig16.ConstraintExclusion.ValueType  # 3

    class _DebugParallelQuery:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DebugParallelQueryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._DebugParallelQuery.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEBUG_PARALLEL_QUERY_UNSPECIFIED: PostgresqlHostConfig16._DebugParallelQuery.ValueType  # 0
        DEBUG_PARALLEL_QUERY_ON: PostgresqlHostConfig16._DebugParallelQuery.ValueType  # 1
        DEBUG_PARALLEL_QUERY_OFF: PostgresqlHostConfig16._DebugParallelQuery.ValueType  # 2
        DEBUG_PARALLEL_QUERY_REGRESS: PostgresqlHostConfig16._DebugParallelQuery.ValueType  # 3

    class DebugParallelQuery(_DebugParallelQuery, metaclass=_DebugParallelQueryEnumTypeWrapper): ...
    DEBUG_PARALLEL_QUERY_UNSPECIFIED: PostgresqlHostConfig16.DebugParallelQuery.ValueType  # 0
    DEBUG_PARALLEL_QUERY_ON: PostgresqlHostConfig16.DebugParallelQuery.ValueType  # 1
    DEBUG_PARALLEL_QUERY_OFF: PostgresqlHostConfig16.DebugParallelQuery.ValueType  # 2
    DEBUG_PARALLEL_QUERY_REGRESS: PostgresqlHostConfig16.DebugParallelQuery.ValueType  # 3

    class _ForceParallelMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ForceParallelModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._ForceParallelMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlHostConfig16._ForceParallelMode.ValueType  # 0
        FORCE_PARALLEL_MODE_ON: PostgresqlHostConfig16._ForceParallelMode.ValueType  # 1
        FORCE_PARALLEL_MODE_OFF: PostgresqlHostConfig16._ForceParallelMode.ValueType  # 2
        FORCE_PARALLEL_MODE_REGRESS: PostgresqlHostConfig16._ForceParallelMode.ValueType  # 3

    class ForceParallelMode(_ForceParallelMode, metaclass=_ForceParallelModeEnumTypeWrapper): ...
    FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlHostConfig16.ForceParallelMode.ValueType  # 0
    FORCE_PARALLEL_MODE_ON: PostgresqlHostConfig16.ForceParallelMode.ValueType  # 1
    FORCE_PARALLEL_MODE_OFF: PostgresqlHostConfig16.ForceParallelMode.ValueType  # 2
    FORCE_PARALLEL_MODE_REGRESS: PostgresqlHostConfig16.ForceParallelMode.ValueType  # 3

    class _LogErrorVerbosity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._LogErrorVerbosity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlHostConfig16._LogErrorVerbosity.ValueType  # 0
        LOG_ERROR_VERBOSITY_TERSE: PostgresqlHostConfig16._LogErrorVerbosity.ValueType  # 1
        LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlHostConfig16._LogErrorVerbosity.ValueType  # 2
        LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlHostConfig16._LogErrorVerbosity.ValueType  # 3

    class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...
    LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlHostConfig16.LogErrorVerbosity.ValueType  # 0
    LOG_ERROR_VERBOSITY_TERSE: PostgresqlHostConfig16.LogErrorVerbosity.ValueType  # 1
    LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlHostConfig16.LogErrorVerbosity.ValueType  # 2
    LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlHostConfig16.LogErrorVerbosity.ValueType  # 3

    class _LogLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._LogLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_LEVEL_UNSPECIFIED: PostgresqlHostConfig16._LogLevel.ValueType  # 0
        LOG_LEVEL_DEBUG5: PostgresqlHostConfig16._LogLevel.ValueType  # 1
        LOG_LEVEL_DEBUG4: PostgresqlHostConfig16._LogLevel.ValueType  # 2
        LOG_LEVEL_DEBUG3: PostgresqlHostConfig16._LogLevel.ValueType  # 3
        LOG_LEVEL_DEBUG2: PostgresqlHostConfig16._LogLevel.ValueType  # 4
        LOG_LEVEL_DEBUG1: PostgresqlHostConfig16._LogLevel.ValueType  # 5
        LOG_LEVEL_INFO: PostgresqlHostConfig16._LogLevel.ValueType  # 12
        LOG_LEVEL_LOG: PostgresqlHostConfig16._LogLevel.ValueType  # 6
        LOG_LEVEL_NOTICE: PostgresqlHostConfig16._LogLevel.ValueType  # 7
        LOG_LEVEL_WARNING: PostgresqlHostConfig16._LogLevel.ValueType  # 8
        LOG_LEVEL_ERROR: PostgresqlHostConfig16._LogLevel.ValueType  # 9
        LOG_LEVEL_FATAL: PostgresqlHostConfig16._LogLevel.ValueType  # 10
        LOG_LEVEL_PANIC: PostgresqlHostConfig16._LogLevel.ValueType  # 11

    class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...
    LOG_LEVEL_UNSPECIFIED: PostgresqlHostConfig16.LogLevel.ValueType  # 0
    LOG_LEVEL_DEBUG5: PostgresqlHostConfig16.LogLevel.ValueType  # 1
    LOG_LEVEL_DEBUG4: PostgresqlHostConfig16.LogLevel.ValueType  # 2
    LOG_LEVEL_DEBUG3: PostgresqlHostConfig16.LogLevel.ValueType  # 3
    LOG_LEVEL_DEBUG2: PostgresqlHostConfig16.LogLevel.ValueType  # 4
    LOG_LEVEL_DEBUG1: PostgresqlHostConfig16.LogLevel.ValueType  # 5
    LOG_LEVEL_INFO: PostgresqlHostConfig16.LogLevel.ValueType  # 12
    LOG_LEVEL_LOG: PostgresqlHostConfig16.LogLevel.ValueType  # 6
    LOG_LEVEL_NOTICE: PostgresqlHostConfig16.LogLevel.ValueType  # 7
    LOG_LEVEL_WARNING: PostgresqlHostConfig16.LogLevel.ValueType  # 8
    LOG_LEVEL_ERROR: PostgresqlHostConfig16.LogLevel.ValueType  # 9
    LOG_LEVEL_FATAL: PostgresqlHostConfig16.LogLevel.ValueType  # 10
    LOG_LEVEL_PANIC: PostgresqlHostConfig16.LogLevel.ValueType  # 11

    class _LogStatement:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._LogStatement.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_STATEMENT_UNSPECIFIED: PostgresqlHostConfig16._LogStatement.ValueType  # 0
        LOG_STATEMENT_NONE: PostgresqlHostConfig16._LogStatement.ValueType  # 1
        LOG_STATEMENT_DDL: PostgresqlHostConfig16._LogStatement.ValueType  # 2
        LOG_STATEMENT_MOD: PostgresqlHostConfig16._LogStatement.ValueType  # 3
        LOG_STATEMENT_ALL: PostgresqlHostConfig16._LogStatement.ValueType  # 4

    class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...
    LOG_STATEMENT_UNSPECIFIED: PostgresqlHostConfig16.LogStatement.ValueType  # 0
    LOG_STATEMENT_NONE: PostgresqlHostConfig16.LogStatement.ValueType  # 1
    LOG_STATEMENT_DDL: PostgresqlHostConfig16.LogStatement.ValueType  # 2
    LOG_STATEMENT_MOD: PostgresqlHostConfig16.LogStatement.ValueType  # 3
    LOG_STATEMENT_ALL: PostgresqlHostConfig16.LogStatement.ValueType  # 4

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlHostConfig16._TransactionIsolation.ValueType  # 0
        TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlHostConfig16._TransactionIsolation.ValueType  # 1
        TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlHostConfig16._TransactionIsolation.ValueType  # 2
        TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlHostConfig16._TransactionIsolation.ValueType  # 3
        TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlHostConfig16._TransactionIsolation.ValueType  # 4

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlHostConfig16.TransactionIsolation.ValueType  # 0
    TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlHostConfig16.TransactionIsolation.ValueType  # 1
    TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlHostConfig16.TransactionIsolation.ValueType  # 2
    TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlHostConfig16.TransactionIsolation.ValueType  # 3
    TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlHostConfig16.TransactionIsolation.ValueType  # 4

    class _XmlBinary:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlBinaryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._XmlBinary.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_BINARY_UNSPECIFIED: PostgresqlHostConfig16._XmlBinary.ValueType  # 0
        XML_BINARY_BASE64: PostgresqlHostConfig16._XmlBinary.ValueType  # 1
        XML_BINARY_HEX: PostgresqlHostConfig16._XmlBinary.ValueType  # 2

    class XmlBinary(_XmlBinary, metaclass=_XmlBinaryEnumTypeWrapper): ...
    XML_BINARY_UNSPECIFIED: PostgresqlHostConfig16.XmlBinary.ValueType  # 0
    XML_BINARY_BASE64: PostgresqlHostConfig16.XmlBinary.ValueType  # 1
    XML_BINARY_HEX: PostgresqlHostConfig16.XmlBinary.ValueType  # 2

    class _XmlOption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig16._XmlOption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_OPTION_UNSPECIFIED: PostgresqlHostConfig16._XmlOption.ValueType  # 0
        XML_OPTION_DOCUMENT: PostgresqlHostConfig16._XmlOption.ValueType  # 1
        XML_OPTION_CONTENT: PostgresqlHostConfig16._XmlOption.ValueType  # 2

    class XmlOption(_XmlOption, metaclass=_XmlOptionEnumTypeWrapper): ...
    XML_OPTION_UNSPECIFIED: PostgresqlHostConfig16.XmlOption.ValueType  # 0
    XML_OPTION_DOCUMENT: PostgresqlHostConfig16.XmlOption.ValueType  # 1
    XML_OPTION_CONTENT: PostgresqlHostConfig16.XmlOption.ValueType  # 2

    RECOVERY_MIN_APPLY_DELAY_FIELD_NUMBER: builtins.int
    SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    TEMP_BUFFERS_FIELD_NUMBER: builtins.int
    WORK_MEM_FIELD_NUMBER: builtins.int
    TEMP_FILE_LIMIT_FIELD_NUMBER: builtins.int
    BACKEND_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    OLD_SNAPSHOT_THRESHOLD_FIELD_NUMBER: builtins.int
    MAX_STANDBY_STREAMING_DELAY_FIELD_NUMBER: builtins.int
    CONSTRAINT_EXCLUSION_FIELD_NUMBER: builtins.int
    CURSOR_TUPLE_FRACTION_FIELD_NUMBER: builtins.int
    FROM_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    JOIN_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    DEBUG_PARALLEL_QUERY_FIELD_NUMBER: builtins.int
    CLIENT_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_ERROR_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_CHECKPOINTS_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DURATION_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_LOCK_WAITS_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_TEMP_FILES_FIELD_NUMBER: builtins.int
    SEARCH_PATH_FIELD_NUMBER: builtins.int
    ROW_SECURITY_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    STATEMENT_TIMEOUT_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    BYTEA_OUTPUT_FIELD_NUMBER: builtins.int
    XMLBINARY_FIELD_NUMBER: builtins.int
    XMLOPTION_FIELD_NUMBER: builtins.int
    GIN_PENDING_LIST_LIMIT_FIELD_NUMBER: builtins.int
    DEADLOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    MAX_PRED_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    ARRAY_NULLS_FIELD_NUMBER: builtins.int
    BACKSLASH_QUOTE_FIELD_NUMBER: builtins.int
    DEFAULT_WITH_OIDS_FIELD_NUMBER: builtins.int
    ESCAPE_STRING_WARNING_FIELD_NUMBER: builtins.int
    LO_COMPAT_PRIVILEGES_FIELD_NUMBER: builtins.int
    QUOTE_ALL_IDENTIFIERS_FIELD_NUMBER: builtins.int
    STANDARD_CONFORMING_STRINGS_FIELD_NUMBER: builtins.int
    SYNCHRONIZE_SEQSCANS_FIELD_NUMBER: builtins.int
    TRANSFORM_NULL_EQUALS_FIELD_NUMBER: builtins.int
    EXIT_ON_ERROR_FIELD_NUMBER: builtins.int
    SEQ_PAGE_COST_FIELD_NUMBER: builtins.int
    RANDOM_PAGE_COST_FIELD_NUMBER: builtins.int
    ENABLE_BITMAPSCAN_FIELD_NUMBER: builtins.int
    ENABLE_HASHAGG_FIELD_NUMBER: builtins.int
    ENABLE_HASHJOIN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXSCAN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXONLYSCAN_FIELD_NUMBER: builtins.int
    ENABLE_MATERIAL_FIELD_NUMBER: builtins.int
    ENABLE_MERGEJOIN_FIELD_NUMBER: builtins.int
    ENABLE_NESTLOOP_FIELD_NUMBER: builtins.int
    ENABLE_SEQSCAN_FIELD_NUMBER: builtins.int
    ENABLE_SORT_FIELD_NUMBER: builtins.int
    ENABLE_TIDSCAN_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_PER_GATHER_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    EFFECTIVE_IO_CONCURRENCY_FIELD_NUMBER: builtins.int
    EFFECTIVE_CACHE_SIZE_FIELD_NUMBER: builtins.int
    constraint_exclusion: global___PostgresqlHostConfig16.ConstraintExclusion.ValueType
    debug_parallel_query: global___PostgresqlHostConfig16.DebugParallelQuery.ValueType
    client_min_messages: global___PostgresqlHostConfig16.LogLevel.ValueType
    log_min_messages: global___PostgresqlHostConfig16.LogLevel.ValueType
    log_min_error_statement: global___PostgresqlHostConfig16.LogLevel.ValueType
    log_error_verbosity: global___PostgresqlHostConfig16.LogErrorVerbosity.ValueType
    log_statement: global___PostgresqlHostConfig16.LogStatement.ValueType
    search_path: builtins.str
    default_transaction_isolation: global___PostgresqlHostConfig16.TransactionIsolation.ValueType
    bytea_output: global___PostgresqlHostConfig16.ByteaOutput.ValueType
    xmlbinary: global___PostgresqlHostConfig16.XmlBinary.ValueType
    xmloption: global___PostgresqlHostConfig16.XmlOption.ValueType
    backslash_quote: global___PostgresqlHostConfig16.BackslashQuote.ValueType
    timezone: builtins.str
    @property
    def recovery_min_apply_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_file_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def backend_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def old_snapshot_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_standby_streaming_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def cursor_tuple_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def from_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def join_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def log_checkpoints(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_duration(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_lock_waits(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_temp_files(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def row_security(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def statement_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def gin_pending_list_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def deadlock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_pred_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def array_nulls(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def default_with_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def escape_string_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def lo_compat_privileges(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def quote_all_identifiers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def standard_conforming_strings(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def synchronize_seqscans(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def transform_null_equals(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def exit_on_error(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def seq_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def random_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def enable_bitmapscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashagg(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashjoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexonlyscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_material(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_mergejoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_nestloop(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_seqscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_sort(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_tidscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_parallel_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers_per_gather(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_io_concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        recovery_min_apply_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_file_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        backend_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        old_snapshot_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_standby_streaming_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        constraint_exclusion: global___PostgresqlHostConfig16.ConstraintExclusion.ValueType = ...,
        cursor_tuple_fraction: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        from_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        join_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        debug_parallel_query: global___PostgresqlHostConfig16.DebugParallelQuery.ValueType = ...,
        client_min_messages: global___PostgresqlHostConfig16.LogLevel.ValueType = ...,
        log_min_messages: global___PostgresqlHostConfig16.LogLevel.ValueType = ...,
        log_min_error_statement: global___PostgresqlHostConfig16.LogLevel.ValueType = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_checkpoints: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_duration: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_error_verbosity: global___PostgresqlHostConfig16.LogErrorVerbosity.ValueType = ...,
        log_lock_waits: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement: global___PostgresqlHostConfig16.LogStatement.ValueType = ...,
        log_temp_files: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        search_path: builtins.str = ...,
        row_security: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        default_transaction_isolation: global___PostgresqlHostConfig16.TransactionIsolation.ValueType = ...,
        statement_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bytea_output: global___PostgresqlHostConfig16.ByteaOutput.ValueType = ...,
        xmlbinary: global___PostgresqlHostConfig16.XmlBinary.ValueType = ...,
        xmloption: global___PostgresqlHostConfig16.XmlOption.ValueType = ...,
        gin_pending_list_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        deadlock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_pred_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        array_nulls: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backslash_quote: global___PostgresqlHostConfig16.BackslashQuote.ValueType = ...,
        default_with_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        escape_string_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        lo_compat_privileges: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        quote_all_identifiers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        standard_conforming_strings: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        synchronize_seqscans: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        transform_null_equals: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        exit_on_error: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        seq_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        random_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        enable_bitmapscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashagg: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashjoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexonlyscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_material: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_mergejoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_nestloop: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_seqscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_sort: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_tidscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_parallel_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers_per_gather: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        timezone: builtins.str = ...,
        effective_io_concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        effective_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["array_nulls", b"array_nulls", "backend_flush_after", b"backend_flush_after", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "from_collapse_limit", b"from_collapse_limit", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_temp_files", b"log_temp_files", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_standby_streaming_delay", b"max_standby_streaming_delay", "old_snapshot_threshold", b"old_snapshot_threshold", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "recovery_min_apply_delay", b"recovery_min_apply_delay", "row_security", b"row_security", "seq_page_cost", b"seq_page_cost", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "transform_null_equals", b"transform_null_equals", "work_mem", b"work_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_nulls", b"array_nulls", "backend_flush_after", b"backend_flush_after", "backslash_quote", b"backslash_quote", "bytea_output", b"bytea_output", "client_min_messages", b"client_min_messages", "constraint_exclusion", b"constraint_exclusion", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "debug_parallel_query", b"debug_parallel_query", "default_transaction_isolation", b"default_transaction_isolation", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "from_collapse_limit", b"from_collapse_limit", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_error_verbosity", b"log_error_verbosity", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_min_error_statement", b"log_min_error_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_temp_files", b"log_temp_files", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_standby_streaming_delay", b"max_standby_streaming_delay", "old_snapshot_threshold", b"old_snapshot_threshold", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "recovery_min_apply_delay", b"recovery_min_apply_delay", "row_security", b"row_security", "search_path", b"search_path", "seq_page_cost", b"seq_page_cost", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "timezone", b"timezone", "transform_null_equals", b"transform_null_equals", "work_mem", b"work_mem", "xmlbinary", b"xmlbinary", "xmloption", b"xmloption"]) -> None: ...

global___PostgresqlHostConfig16 = PostgresqlHostConfig16
